==> huaweicloudsdkrds-3.1.68-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/batch_restore_database_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchRestoreDatabaseResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'restore_result': 'list[PostgreSQLRestoreResult]'
    }

    attribute_map = {
        'restore_result': 'restore_result'
    }

    def __init__(self, restore_result=None):
        """BatchRestoreDatabaseResponse

        The model defined in huaweicloud sdk

        :param restore_result: 表信息
        :type restore_result: list[:class:`huaweicloudsdkrds.v3.PostgreSQLRestoreResult`]
        """
        
        super(BatchRestoreDatabaseResponse, self).__init__()

        self._restore_result = None
        self.discriminator = None

        if restore_result is not None:
            self.restore_result = restore_result

    @property
    def restore_result(self):
        """Gets the restore_result of this BatchRestoreDatabaseResponse.

        表信息

        :return: The restore_result of this BatchRestoreDatabaseResponse.
        :rtype: list[:class:`huaweicloudsdkrds.v3.PostgreSQLRestoreResult`]
        """
        return self._restore_result

    @restore_result.setter
    def restore_result(self, restore_result):
        """Sets the restore_result of this BatchRestoreDatabaseResponse.

        表信息

        :param restore_result: The restore_result of this BatchRestoreDatabaseResponse.
        :type restore_result: list[:class:`huaweicloudsdkrds.v3.PostgreSQLRestoreResult`]
        """
        self._restore_result = restore_result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchRestoreDatabaseResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.1.124-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/batch_restore_database_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchRestoreDatabaseResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'restore_result': 'list[RestoreResult]'
    }

    attribute_map = {
        'restore_result': 'restore_result'
    }

    def __init__(self, restore_result=None):
        """BatchRestoreDatabaseResponse

        The model defined in huaweicloud sdk

        :param restore_result: 表信息
        :type restore_result: list[:class:`huaweicloudsdkrds.v3.RestoreResult`]
        """
        
        super(BatchRestoreDatabaseResponse, self).__init__()

        self._restore_result = None
        self.discriminator = None

        if restore_result is not None:
            self.restore_result = restore_result

    @property
    def restore_result(self):
        """Gets the restore_result of this BatchRestoreDatabaseResponse.

        表信息

        :return: The restore_result of this BatchRestoreDatabaseResponse.
        :rtype: list[:class:`huaweicloudsdkrds.v3.RestoreResult`]
        """
        return self._restore_result

    @restore_result.setter
    def restore_result(self, restore_result):
        """Sets the restore_result of this BatchRestoreDatabaseResponse.

        表信息

        :param restore_result: The restore_result of this BatchRestoreDatabaseResponse.
        :type restore_result: list[:class:`huaweicloudsdkrds.v3.RestoreResult`]
        """
        self._restore_result = restore_result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchRestoreDatabaseResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
